# tada-qq
[![Build Status](https://ahmad88me.semaphoreci.com/badges/tada-qq/branches/master.svg)](https://ahmad88me.semaphoreci.com/projects/tada-qq)
[![codecov](https://codecov.io/gh/oeg-upm/tada-qq/branch/master/graph/badge.svg?token=I9KKJBPLXY)](https://codecov.io/gh/oeg-upm/tada-qq)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6344539.svg)](https://doi.org/10.5281/zenodo.6344539)


[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)
[![Python 3.7](https://img.shields.io/badge/python-3.7-blue.svg)](https://www.python.org/downloads/release/python-370/)
[![Python 3.8](https://img.shields.io/badge/python-3.8-blue.svg)](https://www.python.org/downloads/release/python-380/)


TADA (TAbular Data Annotator) for numeric column. It focuses on distributions to label numeric columns in tabular data.


# To publish
```
python setup.py sdist bdist_wheel
twine upload dist/*
```